**************************
References
**************************

For a more comprehensive set of references please see :ref:`Pugh (2015) <Pugh-2015t>`.

.. _Bayes-1763: 
    
    Bayes, T and Price, R, 1763. **An Essay towards Solving a Problem in the Doctrine of Chances. By the Late Rev. Mr. Bayes F. R. S. Communicated by Mr. Price in a Letter to John Canton A. M. F. R. S.**, *Philosophical Transactions of the Royal Society of London*.

.. _Bernth-2011:

    Bernth, H., and Chapman, C., 2011, **A comparison of the dispersion relations for anisotropic elastodynamic finite-difference grids**, *Geophysics*, 76(3), WA43–WA50.

.. _Beyreuther-2010:

    Beyreuther, M., Barsch, R., Krischer, L., Megies, T., Behr, Y., & Wassermann, J., 2010. **ObsPy: a Python toolbox for seismology**, *SRL Electron. Seismol.*.

.. _Chapman-2011:   

    Chapman, C. H. and Leaney, W. S., 2011. **A new moment-tensor decomposition for seismic events in anisotropic media**, *GJI*, 188(1), 343-370.

.. _Green-1995:

    Green, P J, 1995. **Reversible jump Markov chain Monte Carlo computation and Bayesian model determination**, *Biometrika*, 82(4), 711-732.

.. _Greenfield-2015:
    
    Greenfield, T. & White, R. S., 2015. **Building Icelandic Igneous Crust by Repeated Melt Injections**, *J. Geophys. Res.*, 120(11), 7771-7788.

.. _Hardebeck-2002:

    Hardebeck, J. L. & Shearer, P. M., 2002. **A new method for determining first-motion focal mechanisms**, *Bull. Seismol. Soc. Am.*, 92(6), 2264-2276.

.. _Hardebeck-2003:

    Hardebeck, J. L. & Shearer, P. M., 2003. **Using S / P amplitude ratios to constrain the focal mechanisms of small earthquakes**, *Bull. Seismol. Soc. Am.*, 93(6), 2434-2444.

.. _Hastings-1970:

    Hastings, W K, 1970. **Monte Carlo sampling methods using Markov chains and their applications**, *Biometrika*, 57(1), 97-109.

.. _Hinkley-1969: 
    
    Hinkley, D V, 1969. **On the ratio of two correlated normal random variables**, *Biometrika*, 56(3), 635-639.

.. _Hudson-1989:

    Hudson, J. A., R. G. Pearce, and R. M. Rogers, 1989. **Source type plot for inversion of the moment tensor**, *J. Geophys. Res.*, 94(B1), 765–774.

.. _Laplace-1812: 
    
    Laplace, P S, 1812. **Théorie analytique des probabilités**.

.. _Markov-1954:

    Markov, A A, 1954. **Theory of Algorithms**, *Moscow Academy of Sciences of the USSR* [*Israel Program for Scientific Translations for the National Science Foundation, Washington, D.C., 1961*].

.. _Metropolis-1953:

    Metropolis, N, Rosenbluth, A W, Rosenbluth, M N, Teller, A H, & Teller, E, 1953. **Equation of State Calculations by Fast Computing Machines**, *The Journal of Chemical Physics* 21 pp 1087-1092.

.. _Norris-1998:

    Norris, J R, 1998. **Markov Chains**, *Cambridge University Press*.

.. _Pugh-2015t: 
    
    Pugh, D J, 2015, **Bayesian Source Inversion of Microseismic Events**, *PhD Thesis, Department of Earth Sciences, University of Cambridge*.

.. _Pugh-2016a: 
    
    Pugh, D J, White, R S and Christie, P A F, 2016a, **A Bayesian method for microseismic source inversion**, *GJI*, 206(2), 1009-1038.

.. _Pugh-2016b: 
    
    Pugh, D J, White, R S and Christie, P A F, 2016b, **Automatic Bayesian polarity determination**, *GJI*, 206(1), 275-291.

.. _Pugh-2015f: 
    
    Pugh, D J and White, R S, 2018 **MTfit: A Bayesian Approach to Moment Tensor Inversion**, *Seismological Research Letters*, 89, 1507–1513,

.. _Reasenberg-1985:
    
    Reasenberg, P. A. & Oppenheimer, D., 1985. **FPFIT, FPPLOT and FPPAGE: Fortran computer programs for calculating and displaying earthquake fault-plane solutions** *OFR 85-739, Tech. rep., USGS*.

.. _Riedesel-1989:

    Riedesel, M. A., and T. H. Jordan, 1989. **Display and assessment of seismic moment tensors**, *Bull. Seismol. Soc. Am.*, 79(1), 85–100

.. _Sivia-2000: 
    
    Sivia, D S, 2000. **Data Analysis: A Bayesian Tutorial**, *Oxford Univ. Press*.

.. _Snoke-2003:

    Snoke, J. A., 2003. **FOCMEC: FOCal MEChanism determinations**, *Tech. rep.*.

.. _Tape-2012:

    Tape, C and Tape, W, 2012. **A geometric setting for moment tensors**, *GJI*, 190(1) 476-498.

.. _Watson-2015:

    Mildon, Z K, Pugh D J, Tarasewicz, J, White, R S, Brandsdóttir, B, 2015. **Closing crack earthquakes within the Krafla caldera, North Iceland**, *GJI*, 207, 1137-1141.

.. _Wilks-2015:

    Wilks, M., Bradford, I., Williams, M., Rodriguez, I. V., & Pugh, D., 2015. **Combined use of a deep monitoring array and shallow borehole arrays for moment tensor inversion**, in *77th EAGE Conf. Exhib.*.
